/*
	$Id: daemon.h 421 2005-07-28 13:32:33Z crosser $

	$Log: daemon.h,v $
	Revision 1.7  2003/09/13 18:35:03  crosser
	report config errors to syslog (because if we are respawning there
	is not stderr).  Compile-time warnings.
	
	Revision 1.6  2003/09/03 19:41:39  crosser
	work in progress on changed calling conventions
	
	Revision 1.5  2003/09/01 16:39:22  crosser
	make DSO actually work
	
	Revision 1.4  2003/09/01 09:39:21  crosser
	add head comments where necessary
	add run time config function
	
	Revision 1.3  2003/08/31 18:43:23  crosser
	make the thing run in "filter" mode - from stdin to stdout
	
	Revision 1.2  2003/08/31 12:58:58  crosser
	make basic separation of lib/ plugins
	configure REPLACE_FUNCS in a right way (hopefully)
	
	Revision 1.1  2003/08/31 11:48:46  crosser
	filling inc and lib
	
*/

/*
	WHAT IS IT:
		modularized contentfilter for Zmailer
	COPYRIGHT:
		(c) 2003 Eugene G. Crosser <crosser@average.org>
	LICENSE:
		The same set as apply to Zmailer code
*/

#ifndef DAEMON_H
#define DAEMON_H

#define MAXFD 255

extern void
givebirth(int ctlsock,int argc,char *argv[]);

extern void
processfile(char *fn,varpool_t vp);

extern int
mainloop(int ctlsock,int argc, char *argv[]);

extern void
taspoolid(char *buf,time_t mtime,long inodenum);

extern void
getmyfqdn(char *name,size_t len,char *confdomain);

extern int runchild;
extern int stayalive;
extern int isdaemon;

extern char myfqdn[];

#endif
